pub enum BatchMode {
Native,
FanOut,
}Expand description
How a provider fulfills a request for more than one output image.
Variants
Native
One upstream provider operation can return the requested output count.
FanOut
The bridge fans the request out into multiple bounded upstream operations.