pub enum SupportLevel {
Native,
Emulated,
Unsupported,
}Expand description
Degree to which a provider supports a semantic feature.
Variants
Native
The provider handles the feature natively.
Emulated
The bridge can emulate the feature with a reported transformation.
Unsupported
The feature is unavailable.