pub enum TransparencyMode {
Auto,
Native,
ChromaKey,
}Expand description
How a transparent-background result is produced.
Variants
Auto
Prefer native alpha and otherwise use a local chroma-key matte.
Wire value auto.
Native
Require provider-native alpha output.
Wire value native.
ChromaKey
Generate a flat key background and remove it locally.
Wire value chroma_key.